@@ -457,6 +457,7 @@ mod tests {
 
     use cylinder::{secp256k1::Secp256k1Context, Context, Signer};
 
+    use crate::context::ContextId;
     use crate::execution::adapter::test_adapter::TestExecutionAdapter;
     use crate::protocol::transaction::{HashMethod, TransactionBuilder, TransactionPair};
     use crate::scheduler::ExecutionTaskCompletionNotification;
@@ -688,7 +689,7 @@ mod tests {
     fn create_txn(signer: &dyn Signer) -> TransactionPair {
         TransactionBuilder::new()
             .with_batcher_public_key(hex::decode(KEY1).unwrap())
-            .with_dependencies(vec![hex::decode(KEY2).unwrap(), hex::decode(KEY3).unwrap()])
+            .with_dependencies(vec![KEY2.to_string(), KEY3.to_string()])
             .with_family_name(FAMILY_NAME.to_string())
             .with_family_version(FAMILY_VERSION.to_string())
             .with_inputs(vec![
@@ -700,14 +701,14 @@ mod tests {
                 hex::decode(KEY6).unwrap(),
                 hex::decode(&KEY7[0..4]).unwrap(),
             ])
-            .with_payload_hash_method(HashMethod::SHA512)
+            .with_payload_hash_method(HashMethod::Sha512)
             .with_payload(BYTES2.to_vec())
             .build_pair(signer)
             .expect("The TransactionBuilder was not given the correct items")
     }
 
     fn create_iterator() -> impl Iterator<Item = ExecutionTask> {
-        let context_id = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0];
+        let context_id = ContextId::default();
         let signer = new_signer();
 
         (0..NUMBER_OF_TRANSACTIONS)
