@@ -1,6 +1,6 @@
 /*
  * Copyright 2018 Bitwise IO, Inc.
- * Copyright 2019 Cargill Incorporated
+ * Copyright 2019-2021 Cargill Incorporated
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -122,26 +122,41 @@ extern crate diesel;
 #[macro_use]
 extern crate diesel_migrations;
 
+#[cfg(feature = "context")]
+mod collections;
+#[cfg(feature = "context")]
 pub mod context;
 #[cfg(feature = "contract")]
 pub mod contract;
 pub mod database;
 pub mod error;
+#[cfg(feature = "execution")]
 pub mod execution;
 pub mod families;
+#[cfg(feature = "handler")]
 pub mod handler;
 pub mod protocol;
 #[allow(renamed_and_removed_lints)]
 pub mod protos;
 #[cfg(feature = "sawtooth-compat")]
 pub mod sawtooth;
+#[cfg(feature = "scheduler")]
 pub mod scheduler;
 pub mod state;
 #[cfg(feature = "workload")]
 pub mod workload;
 
+// #[macro_use]` on the `sabre-sdk` enables the sabre log macros, this however cannot be
+// enabled at the same time as the `log` crate's macros due to linker conflicts
+#[cfg(all(feature = "sabre-compat", feature = "log"))]
+compile_error!("Incompatible features enabled: 'sabre-compat' and 'log'");
+
+#[cfg(feature = "log")]
 #[macro_use]
 extern crate log;
+#[cfg(feature = "sabre-compat")]
+#[macro_use]
+extern crate sabre_sdk;
 #[cfg(feature = "serde_derive")]
 #[macro_use]
 extern crate serde_derive;
